@@ -1,9 +1,6 @@
 package PDK::Device::Huawei::Usg;
 
-use 5.030;
-use strict;
-use warnings;
-
+use v5.30;
 use Moose;
 use Expect qw'exp_continue';
 use Carp   qw'croak';
@@ -13,10 +10,7 @@ use namespace::autoclean;
 sub getConfig {
   my $self = shift;
 
-  my $commands = [
-
-    "screen-width 512", "screen-length 512 temporary", "dis current-configuration", "save"
-  ];
+  my $commands = ["screen-width 512", "screen-length 512 temporary", "dis current-configuration", "save"];
 
   my $config = $self->execCommands($commands);
 
@@ -25,8 +19,6 @@ sub getConfig {
   }
   else {
     my $lines = $config->{result};
-
-
     return {success => 1, config => $lines};
   }
 }
@@ -34,16 +26,20 @@ sub getConfig {
 sub ftpConfig {
   my ($self, $hostname, $server, $username, $password) = @_;
 
+  if (!$self->{exp}) {
+    my $login = $self->login();
+    croak $login->{reason} if $login->{success} == 0;
+  }
+
   $server   //= $ENV{PDK_FTP_SERVER};
   $username //= $ENV{PDK_FTP_USERNAME};
   $password //= $ENV{PDK_FTP_PASSWORD};
 
-  croak "请正确提供 FTP 服务器地址、账户和密码!" unless $username and $password and $server;
+  croak "请正确提供 FTP 服务器地址、账户和密码或者设置相关环境变量!" unless $username and $password and $server;
 
   my $host    = $self->{host};
   my $command = "put config.cfg $self->{month}/$self->{date}/";
 
-
   if ($hostname) {
     $command .= $hostname . '_' . $host . '.cfg';
   }
@@ -51,41 +47,37 @@ sub ftpConfig {
     $command .= $host . '.cfg';
   }
 
-  if (!$self->{exp}) {
-    my $login = $self->login();
-    croak $login->{reason} if $login->{success} == 0;
-  }
-
   my $exp    = $self->{exp};
-  my $result = $exp ? $exp->match() : "";
+  my $result = $exp ? $exp->match() || '' : '';
 
   my $ftp_cmd = "ftp $server vpn-instance default";
-  say "[debug] 生成 FTP 备份指令：$ftp_cmd" if $self->{debug};
+  $self->dump("生成 FTP 备份指令：$ftp_cmd");
 
-  $exp->send("$ftp_cmd\n");
+  $self->dump("准备连接 FTP 服务器");
+  $self->send("$ftp_cmd\n");
   my @ret = $exp->expect(
     15,
     [
       qr/User\s*\(/i => sub {
+        $self->send("$username\n");
         $result .= $exp->before() . $exp->match();
-        $exp->send("$username\n");
         exp_continue;
       }
     ],
     [
       qr/assword:/i => sub {
+        $self->send("$password\n");
         $result .= $exp->before() . $exp->match();
-        $exp->send("$password\n");
       }
     ],
     [
       eof => sub {
-        croak("执行[ftpConfig/登录FTP服务器]，与设备 $self->{host} 会话丢失，连接被意外关闭！具体原因：\n" . $exp->before());
+        croak("执行[ftpConfig/登录FTP服务器]，与设备 $self->{host} 会话丢失，连接被意外关闭！\n" . $exp->before());
       }
     ],
     [
       timeout => sub {
-        croak("执行[ftpConfig/登录FTP服务器]，与设备 $self->{host} 会话超时，请检查网络连接或服务器状态！具体原因：\n" . $exp->before());
+        croak("执行[ftpConfig/登录FTP服务器]，与设备 $self->{host} 会话超时！\n" . $exp->before());
       }
     ],
   );
@@ -96,58 +88,61 @@ sub ftpConfig {
     10,
     [
       qr/(ftp: Login failed.|Username)/i => sub {
-        croak("FTP 会话丢失: username or password is wrong!");
+        croak("FTP 登录失败: 用户名或密码错误！");
       }
     ],
     [
       qr/User logged in/i => sub {
         $result .= $exp->before() . $exp->match();
-        say "[debug] 成功连接 FTP 服务器($server)" if $self->{debug};
+        $self->dump("成功连接 FTP 服务器($server)");
       }
     ],
     [
       eof => sub {
-        croak("执行[ftpConfig/检查是否成功登录FTP]，与设备 $self->{host} 会话丢失，连接被意外关闭！具体原因：\n" . $exp->before());
+        croak("执行[ftpConfig/检查是否成功登录FTP]，与设备 $self->{host} 会话丢失！\n" . $exp->before());
       }
     ],
     [
       timeout => sub {
-        croak("执行[ftpConfig/检查是否成功登录FTP]，与设备 $self->{host} 会话超时，请检查网络连接或服务器状态！具体原因：\n" . $exp->before());
-      }
-    ],
-  );
-
-  $exp->send("$command\n");
-  @ret = $exp->expect(
-    15,
-    [
-      qr/(No such file or directory|The system cannot)/i => sub {
-        croak "执行脚本 $command 异常，上传失败!";
-      }
-    ],
-    [
-      qr/Transfer complete.*ftp[>\]]/ms => sub {
-        $result .= $exp->before() . $exp->match() . $exp->after();
-        say "\n[debug] 脚本 $command 已执行完毕, 文件上传成功!" if $self->{debug};
-      }
-    ],
-    [
-      eof => sub {
-        croak("执行[ftpConfig/检查备份任务是否成功]，与设备 $self->{host} 会话丢失，连接被意外关闭！具体原因：\n" . $exp->before());
-      }
-    ],
-    [
-      timeout => sub {
-        croak("执行[ftpConfig/检查备份任务是否成功]，与设备 $self->{host} 会话超时，请检查网络连接或服务器状态！具体原因：\n" . $exp->before());
+        croak("执行[ftpConfig/检查是否成功登录FTP]，与设备 $self->{host} 会话超时！\n" . $exp->before());
       }
     ],
   );
 
   croak($ret[3]) if defined $ret[1];
-  $exp->send("quit\n");
+
+  $self->send("$command\n");
+  @ret = $exp->expect(
+    15,
+    [
+      qr/(No such file or directory|The system cannot)/i => sub {
+        croak "执行脚本 $command 异常，上传失败！";
+      }
+    ],
+    [
+      qr/Transfer complete.*ftp[>\]]/ms => sub {
+        $result .= $exp->before() . $exp->match() . $exp->after();
+        $self->dump("脚本 $command 已执行完毕, 文件上传成功");
+      }
+    ],
+    [
+      eof => sub {
+        croak("执行[ftpConfig/检查备份任务是否成功]，与设备 $self->{host} 会话丢失！\n" . $exp->before());
+      }
+    ],
+    [
+      timeout => sub {
+        croak("执行[ftpConfig/检查备份任务是否成功]，与设备 $self->{host} 会话超时！\n" . $exp->before());
+      }
+    ],
+  );
+
+  croak($ret[3]) if defined $ret[1];
+  $self->send("quit\n");
 
   return {success => 1, config => $result};
 }
 
 __PACKAGE__->meta->make_immutable;
+
 1;
